@@ -6,7 +6,15 @@ from rath.operation import Operation
 
 
 class ComposedLink(TerminatingLink):
+    """A composed link is a link that is composed of multiple links. The links
+    are executed in the order they are passed to the constructor.
+
+    The first link in the chain is the first link that is executed. The last
+    link in the chain is the terminating link, which is responsible for sending
+    the operation to the server.
+    """
     links: List[Link]
+    """The links that are composed to form the chain. pydantic will validate that the last link is a terminating link."""
 
     @validator("links")
     def validate(cls, value):
@@ -35,6 +43,8 @@ class ComposedLink(TerminatingLink):
             await link.adisconnect()
 
     async def __aenter__(self):
+
+        # We need to make sure that the links are connected in the correct order
         for i in range(len(self.links) - 1):
             self.links[i].set_next(self.links[i + 1])
 
@@ -51,6 +61,12 @@ class ComposedLink(TerminatingLink):
 
 
 class TypedComposedLink(TerminatingLink):
+    """A typed composed link is a base class to create a definition for
+    a composed link. It is a link that is composed of multiple links that
+    will be set at compile time and not at runtime. Just add links
+    that you want to use to the class definition and they will be
+    automatically composed together.
+    """
     _firstlink: Link = None
 
     async def aconnect(self):
@@ -95,8 +111,12 @@ class TypedComposedLink(TerminatingLink):
 
 
 def compose(*links: Link) -> ComposedLink:
-    """
-    Composes a list of Links into a single Link.
-    """
+    """Compose a chain of links together. The first link in the chain is the first link that is executed.
+    The last link in the chain is the terminating link, which is responsible for sending the operation to the server.
+
+
+    Returns:
+        ComposedLink: The composed link
+    """   
 
     return ComposedLink(links=links)
