@@ -7,12 +7,12 @@ from rath.links.parsing import ParsingLink
 
 def parse_variables(
     variables: Dict,
+    by_alias: bool = True,
 ) -> Dict:
     def recurse_extract(obj):
         """
         recursively traverse obj, doing a deepcopy, but
-        replacing any file-like objects with nulls and
-        shunting the originals off to the side.
+        replacing any  pydantic BaseModels with their dict representation
         """
 
         if isinstance(obj, list):
@@ -28,7 +28,7 @@ def parse_variables(
                 nulled_obj[key] = value
             return nulled_obj
         elif isinstance(obj, BaseModel):
-            return json.loads(obj.json(by_alias=True))
+            return json.loads(obj.json(by_alias=by_alias))
         else:
             # base case: pass through unchanged
             return obj
@@ -39,7 +39,16 @@ def parse_variables(
 
 
 class DictingLink(ParsingLink):
+    """Dicting Link is a link that converts pydantic models to dicts.
+    It traversed the variables dict, and converts any (nested) pydantic models to dicts
+    by callind their .json() method."""
+    by_alias = True
+    """Converts pydantic models to dicts by calling their .json() method with by_alias=True"""
+    
+
+
+
     async def aparse(self, operation: Operation) -> Operation:
-        shrinked_variables = parse_variables(operation.variables)
+        shrinked_variables = parse_variables(operation.variables, by_alias=self.by_alias)
         operation.variables.update(shrinked_variables)
         return operation
