@@ -13,6 +13,10 @@ class ShrinkByID:
 
 
 class ShrinkingLink(ParsingLink):
+    
+    """Shrinking Link is a link that shrinks operation variables.
+    It traverses the variables dict, and converts any model that has a .ashrink() method to its id."""
+
     async def aparse(self, operation: Operation) -> Operation:
 
         shrinked_variables = {
